/*  rgd_ckmnmx.c -- Update minimum/maximum coordinate values

NAME:
    rgd_ckmnmx ()

PURPOSE:
    Called by rgd_outbox() and rgd_inrect(), as part of program REGRID,
    to check a pair of line and sample values against the current minima
    and maxima, and update these if necessary.

ARGUMENTS:

    float   y		 (in)	Coordinate y-value (e.g., image line).
    float   x		 (in)	Coordinate x-value (sample of line).
    float   minmax[2][2] (mod)	Minimum (y,x) and maximum (y,x).

RETURN VALUE:
    None.

PROGRAM HISTORY:                                  
    1993-12	Initial version, R. A. White, PSU/ORSER.
    2005-03	Updated for LAS 7.4 and Linux, raw.

COMPUTER HARDWARE AND/OR SOFTWARE LIMITATIONS:
    This program runs under the TAE/LAS environment.
    It has been tested under Solaris 2.X and Linux 2.4.

PROJECT:
    PSU/ORSER

***************   Start of Function rgd_ckmnmx   ***************	*/

#include	"las.h"		/* Standard LAS include files */
void FUNCTION rgd_ckmnmx (
    float	y,		/* First coordinate to be checked */
    float	x,		/* Second coordinate to be checked */
    float	minmax[2][2])	/* Current minima and maxima */
    {
    if (minmax[0][0] > y)
	minmax[0][0] = y;
    if (minmax[0][1] > x)
	minmax[0][1] = x;
    if (minmax[1][0] < y)
	minmax[1][0] = y;
    if (minmax[1][1] < x)
	minmax[1][1] = x;

    return;
    }			/* End of Function rgd_ckmnmx	*/
